// jshint maxerr:1000
/* ---------------------------------------------------------------------------------------------------------

    SCRIBBLEMAKES - IMAGE CLICK TO ENLARGE PLUGIN V1.0
    -------------------------------------------
    Last updated: 8th August 2023
    
    Welcome to the Image Click to Enlarge Plugin (ICEP)! This plugin edits every image, or the list of
      images you provide, so they can be clicked on to make them full screen. To integrate into your 
      website, save this .js file to it and follow the instructions in the 'more information' link
      (https://scribblemakes.com/code/development#sc_icep). 
      You will need to fill in the required variables below.
      
    To include this correctly in your web page, you can copy this html code just above your </body> tag,
      replace 'URLPATHWAY' with your website URL or the local pathway to it:
    ---------------------------------------------------------------------------------------- Start HTML Code
    <script src="URLPATHWAY/scPlugin_ImageClicktoEnlarge.js" type="text/javascript"></script>
    ------------------------------------------------------------------------------------------ End HTML Code
    
    --------------------------------------
    
    /‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾\  Looking for more tutorials, widgets, and plugins?       /‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾\  
   ｜  ❮‾ |\  /|  / ⎡‾‾  ｜  Get them at my personal website or LHClubhouse room   ｜  ❮‾ |\  /|  / ⎡‾‾  ｜
   ｜  _❯ | \/ | /  ⎣__  ｜   https://scribblemakes.com/code                       ｜  _❯ | \/ | /  ⎣__  ｜  
    \___________________/    https://lordhorse.neocities.org/office/home           \____________________/ 
        
    --------------------------------------
    
    For more information on this script:
    https://scribblemakes.com/code/development#sc_icep
      
--------------------------------------------------------------------------------------------------------- */

// FILL IN ANY VARIABLES BELOW IF YOU WANT TO CHANGE THEM FROM THE DEFAULT

const sc_icep_runType = "all"; // Set to "all" to set all images, set to "class" to only get select images
const sc_icep_ignoreClass = "ff_imgNoEnlarge"; // Plugin will ignore images with this class
const sc_icep_onlyClass = "ff_imgEnlarge"; // If sc_icep_runType = "class", it will only enlarge this class
const sc_icep_gallery = true; // If the user can click arrows on the left and right to see more images
const sc_icep_altShow = true;  // Displays ALT text in image viewer as a caption
  
const sc_icep_imgsViewerCSSBG = "rgba(0,0,0,0.8)";  // What background colour the viewer has
const sc_icep_imgsViewerCSSText = "white";  // What text colour the viewer has
const sc_icep_galleryPrevText = "<";  // What text is in the previous button
const sc_icep_galleryNextText = ">";  // What text is in the next button
const sc_icep_galleryButtonCSSHover = "black";  // What colour the button bg is when hovered over
const sc_icep_imgsTextCSSHeight = "5em";  // How tall the alt text caption is
const sc_icep_imgsTextCSSBG = "black";  // What colour the alt text background is
const sc_icep_galleryMobileView = "800px";   
  // What size the buttons move to the bottom, set to 9999px or higher for permanent bottom buttons

// NOTE: Changing the sc_icep_ignoreClass variable may break compatibility with other widgets / plugins
  // If you want to maintain compatibility, do a search and replace for "sc_icep_noEnlarge" with your new
  // ignore class on any scripts you want to correct.


// ---------------------------------------------------------------------------------------------------------
// ---------------------- DO NOT EDIT PAST THIS POINT UNLESS PROFICIENT IN JAVASCRIPT ----------------------
// ---------------------------------------------------------------------------------------------------------

// Collect images
var sc_icep_imgs = [];
if (sc_icep_runType == "all") {
  sc_icep_imgs = document.querySelectorAll('img:not(.' + sc_icep_ignoreClass + ')');
} else {
  sc_icep_imgs = document.querySelectorAll('.' + sc_icep_onlyClass + ':not(.' + sc_icep_ignoreClass + ')');
}

// Collect image src and alt code
const sc_icep_src = [];
const sc_icep_alt = [];
for (let sc_icep_i = 0; sc_icep_i < sc_icep_imgs.length; sc_icep_i++) {
  sc_icep_src.push(sc_icep_imgs[sc_icep_i].src);
  sc_icep_alt.push(sc_icep_imgs[sc_icep_i].alt);
  if (sc_icep_imgs[sc_icep_i].parentNode.nodeName != "A"){
    sc_icep_imgs[sc_icep_i].tabIndex = 0; // Make images selectable by tab
    sc_icep_imgs[sc_icep_i].style.cursor = "pointer"; // Make images look clickable
  }
}


// Create image overlay element
const sc_icep_imgsViewer = document.createElement('div');
  sc_icep_imgsViewer.id = "sc_icep_imgsViewer";
  document.body.appendChild(sc_icep_imgsViewer);
  const sc_icep_imgsViewerBox = document.createElement('div');
  sc_icep_imgsViewerBox.id = "sc_icep_imgsViewerBox";
  sc_icep_imgsViewer.appendChild(sc_icep_imgsViewerBox);
  
  // Create element that holds the image in the viewer
  const sc_icep_imgsHolder = document.createElement('div');
  sc_icep_imgsHolder.id = "sc_icep_imgsHolder";
  sc_icep_imgsViewerBox.appendChild(sc_icep_imgsHolder);
  
  // Create element that holds the ALT text (if needed)
  if (sc_icep_altShow) {
    const sc_icep_imgsText = document.createElement('div');
    sc_icep_imgsText.id = "sc_icep_imgsText";
    sc_icep_imgsViewer.appendChild(sc_icep_imgsText);
  }
  
  // Create left and right buttons for galleries
  if (sc_icep_gallery) {
    const sc_icep_galleryPrev = document.createElement('div'), sc_icep_galleryNext = document.createElement('div');
    sc_icep_galleryPrev.id = "sc_icep_galleryPrev"; sc_icep_galleryNext.id = "sc_icep_galleryNext";
    sc_icep_galleryPrev.classList.add("sc_icep_galleryButton"); sc_icep_galleryNext.classList.add("sc_icep_galleryButton");
    sc_icep_imgsViewerBox.insertBefore(sc_icep_galleryPrev, sc_icep_imgsViewerBox.children[0]); sc_icep_imgsViewerBox.appendChild(sc_icep_galleryNext);
  }
  
  // Give necessary CSS styling for function
  var sc_icep_imgsViewerCSS = document.createElement("style");
  sc_icep_imgsViewerCSS.innerText = 
    `#sc_icep_imgsViewer {
        display:none; 
        position:fixed; 
        top:0;
        left:0;
        width:100%; 
        height:100%; 
        background-color:` + sc_icep_imgsViewerCSSBG + `; 
        z-index:9999999999
      }
      #sc_icep_imgsViewerBox {
        box-sizing:border-box;
        position:relative;
        display:table;
        width:100%;
        height:100%;
      }
      #sc_icep_imgsHolder {
        display:table-cell;
        vertical-align:middle;
        height:100%;
        background-position:center;
        background-repeat:no-repeat;
        background-size:contain;
        cursor:pointer;
      }
      #sc_icep_imgsText {
        box-sizing:border-box;
        position:relative;
        display:block;
        overflow-x:hidden;
        overflow-y:auto;
        width:100%;
        background-color:` + sc_icep_imgsTextCSSBG + `; 
        color:` + sc_icep_imgsViewerCSSText + `;
      }
      .sc_icep_galleryButton {
        box-sizing:border-box;
        display:table-cell;
        vertical-align:middle;
        padding:10px;
        width:2.5em;
        height:100%;
        text-align:center;
        font-size:2.5em;
        cursor:pointer;
      }
      .sc_icep_galleryButton:hover {
        background-color:` + sc_icep_galleryButtonCSSHover + `; 
      }
      #sc_icep_galleryPrev {color:` + sc_icep_imgsViewerCSSText + `;}
      #sc_icep_galleryPrev::after {content:"` + sc_icep_galleryPrevText + `"}
      #sc_icep_galleryNext {color:` + sc_icep_imgsViewerCSSText + `;}
      #sc_icep_galleryNext::after {content:"` + sc_icep_galleryNextText + `"}`;
  if (sc_icep_gallery) {
    sc_icep_imgsViewerCSS.innerText +=
    `@media only screen and (max-width: ` + sc_icep_galleryMobileView + `) {
        #sc_icep_imgsHolder {
          width:100%;
        }
        #sc_icep_imgsText {
          margin-left:calc(2.5em * 2.5);
          width:calc(100% - (5em * 2.5));
        }
        .sc_icep_galleryButton {
          position:fixed;
          display:block;
          bottom:0;
          height:calc(` + sc_icep_imgsTextCSSHeight + ` / 2.5);
        }
        #sc_icep_galleryPrev {left:0;}
        #sc_icep_galleryNext {right:0;}
      }`;
  }
  document.head.appendChild(sc_icep_imgsViewerCSS);



// Set up 'onclick' function
var sc_icep_imgsIndex = 0;
function sc_icep_ImgsShow(sc_icep_num) {
  // Change image position if given an argument
  if (sc_icep_num) {
    sc_icep_imgsIndex += sc_icep_num;
  }
  
  // Make viewer visible
  sc_icep_imgsViewer.style.display = "block";
  
  // Set up which image is displaying
  sc_icep_imgsHolder.style.backgroundImage = 'url(' + sc_icep_src[sc_icep_imgsIndex] + ')';
  // Set up alt text if available AND turned on
  if (sc_icep_altShow && sc_icep_alt[sc_icep_imgsIndex] != "") {
    sc_icep_imgsText.innerText = sc_icep_alt[sc_icep_imgsIndex];
    sc_icep_imgsText.style.height = sc_icep_imgsTextCSSHeight;
    sc_icep_imgsViewerBox.style.height = "calc(100% - " + sc_icep_imgsTextCSSHeight + ")";
  } else if (sc_icep_altShow) {
    sc_icep_imgsText.style.height = "0px";
    sc_icep_imgsViewerBox.style.height = "100%";
  }
  
  // Set up the left and right buttons for the gallery
  if (sc_icep_gallery){
    if (sc_icep_imgsIndex < sc_icep_src.length-1) {
      sc_icep_galleryNext.style.pointerEvents = "auto";
      sc_icep_galleryNext.style.opacity = "100%";
    } else {
      sc_icep_galleryNext.style.pointerEvents = "none";
      sc_icep_galleryNext.style.opacity = "30%";
    }
    if (sc_icep_imgsIndex > 0) {
      sc_icep_galleryPrev.style.pointerEvents = "auto";
      sc_icep_galleryPrev.style.opacity = "100%";
    } else {
      sc_icep_galleryPrev.style.pointerEvents = "none";
      sc_icep_galleryPrev.style.opacity = "30%";
    }
  }
}

// Set up closing function
function sc_icep_ImgsHide() {
  sc_icep_imgsViewer.style.display = "none";
}


// Give all images an onclick and onkeydown function
sc_icep_imgs.forEach(img => {
  img.addEventListener('click', function() {
    sc_icep_imgsIndex = sc_icep_src.indexOf(this.src);
    sc_icep_ImgsShow();
  });
  img.addEventListener('keydown', function(e) {
    if (e.keyCode == 13) {
      sc_icep_imgsIndex = sc_icep_src.indexOf(this.src);
      sc_icep_ImgsShow();
    }
  });
});


// Give image holder an onclick function to hide it if clicked
sc_icep_imgsHolder.addEventListener('click', function() {
  sc_icep_ImgsHide();
});

// Give gallery left and right buttons their onclick code
if (sc_icep_gallery) {
  sc_icep_galleryPrev.addEventListener('click', function() {
    sc_icep_ImgsShow(-1);
  });
  sc_icep_galleryNext.addEventListener('click', function() {
    sc_icep_ImgsShow(1);
  });
}


// Adds a document listener to allow for image viewer hiding & left / right button clicking for the gallery
document.addEventListener("keydown", function(e) {
  if (sc_icep_imgsViewer.style.display == "block") {
    if (e.keyCode == 27) {
      sc_icep_ImgsHide();
    } else if (e.keyCode == 37 && sc_icep_imgsIndex > 0 && sc_icep_gallery) {
      sc_icep_ImgsShow(-1);
    } else if (e.keyCode == 39 && sc_icep_imgsIndex < sc_icep_src.length-1 && sc_icep_gallery) {
      sc_icep_ImgsShow(1);
    }
  }
});



